# image_manipulator_thx

Pacote python com vários módulos par amanipular image.

Serve como template para outros pacotes

Description. 
The package image_manipulator is used to:
	Processing:
		- Histogram matching
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image_manipulator

```bash
pip install image_manipulator
```

## Author
Alex Pivato

## License
[MIT](https://choosealicense.com/licenses/mit/)
